#include "solver_25x25_interface.h"

vector<double> Solver25x25Interface::solve(vector<double>& S, vector<double>& B, double W, double H, double LW, double LH)
{
    CVXGenImageResizing25x25 cvx_25x25;
    
    cvx_25x25.set_defaults();
    cvx_25x25.settings.verbose = 0;
    cvx_25x25.setup_indexing();
    
    
    cvx_25x25.params.imageWidth[0] = W;
    cvx_25x25.params.imageHeight[0] = H;
    cvx_25x25.params.minLengthW[0] = LW;
    cvx_25x25.params.minLengthH[0] = LH;
    
    for(int i = 0; i < NUM_DOF; i++)
    {
        for(int j = 0; j < NUM_DOF; j++)
        {
            cvx_25x25.params.E[i*NUM_DOF + j] = S[i*NUM_DOF + j];
        }
    }

    for(int i = 0; i < NUM_DOF; i++)
    {
        cvx_25x25.params.B[i] = B[i];
    }
    
    for(int i = 0; i < NUM_DOF; i++)
    {
        cvx_25x25.vars.st[i] = 0.0;
    }
    
    //solving the quadratic program
    long int num_iters = cvx_25x25.solve();
    
    //std::cout << "The number of iterations is: " << num_iters << ".\n";
    
//    double width = 0.0;
//    for(int i = 0; i < DOF_IN_X; i++)
//    {
//        std::cout << cvx_25x25.vars.st[i] << "\n";
//        width += cvx_25x25.vars.st[i];
//    }
//    
//    std::cout << "Solver returned width: " << width << ".\n";
//    
//    double height = 0.0;
//    for(int i = 0; i < DOF_IN_Y; i++)
//    {
//        std::cout << cvx_25x25.vars.st[i + DOF_IN_X] << "\n";
//        height += cvx_25x25.vars.st[i + DOF_IN_X];
//    }
//    
//    std::cout << "Solver returned height: " << height << ".\n";
    
    vector<double> res(NUM_DOF);
    for(int i = 0; i < NUM_DOF; i++)
        res[i] = cvx_25x25.vars.st[i];
    return res;
}
